'use strict';

var _chai = require('chai');

var _constructorIndexInArray = require('../constructorIndexInArray');

var _constructorIndexInArray2 = _interopRequireDefault(_constructorIndexInArray);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint-disable no-unused-expressions */


describe('constructorIndexInArray', function () {
  it('should find normal function declarations', function () {
    function CommonsChunkPlugin() {}
    var array = [new CommonsChunkPlugin()];
    (0, _chai.expect)((0, _constructorIndexInArray2.default)(array, 'CommonsChunkPlugin')).to.equal(0);
  });

  it('should find it, not depending on the options passed', function () {
    function CommonsChunkPlugin() {}
    var array = [new CommonsChunkPlugin({
      some: 'options'
    })];
    (0, _chai.expect)((0, _constructorIndexInArray2.default)(array, 'CommonsChunkPlugin')).to.equal(0);
  });

  it('should find it at other places than the first', function () {
    function SomeOtherPlugin() {}
    function CommonsChunkPlugin() {}
    var array = [new SomeOtherPlugin(), new CommonsChunkPlugin()];
    (0, _chai.expect)((0, _constructorIndexInArray2.default)(array, 'CommonsChunkPlugin')).to.equal(1);
  });

  it('should find ES6 arrow functions', function () {
    var CommonsChunkPlugin = function CommonsChunkPlugin() {};
    var array = [new CommonsChunkPlugin()];
    (0, _chai.expect)((0, _constructorIndexInArray2.default)(array, 'CommonsChunkPlugin')).to.equal(0);
  });

  it('should throw if the first argument is not an array', function () {
    (0, _chai.expect)(_constructorIndexInArray2.default).to.throw(/The first argument must be an array/);
  });

  it('should not find non-instantiated classes', function () {
    var CommonsChunkPlugin = function CommonsChunkPlugin() {};
    var array = [CommonsChunkPlugin()];
    (0, _chai.expect)((0, _constructorIndexInArray2.default)(array, 'CommonsChunkPlugin')).to.be.false;
  });
});