'use strict';

var _chai = require('chai');

var _emitAssets = require('../emitAssets');

var _emitAssets2 = _interopRequireDefault(_emitAssets);

var _sinon = require('sinon');

var _sinon2 = _interopRequireDefault(_sinon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('emitAssets', function () {
  var compilation = void 0;

  beforeEach(function () {
    compilation = {
      assets: {}
    };
  });

  it('should add to compilation.assets', function () {
    // Setup
    var assets = {
      'bundle.js': 'some code here'
    };
    var callback = _sinon2.default.spy();
    // Do it
    (0, _emitAssets2.default)(compilation, assets, '', callback);
    (0, _chai.expect)(compilation.assets['bundle.js']).to.exist;
  });

  it('should add both source and size to a compilation.assets asset', function () {
    // Setup
    var assets = {
      'bundle.js': 'some code here'
    };
    var callback = _sinon2.default.spy();
    // Do it
    (0, _emitAssets2.default)(compilation, assets, '', callback);
    (0, _chai.expect)(compilation.assets['bundle.js']).to.exist;
    (0, _chai.expect)(compilation.assets['bundle.js'].source).to.be.a.function;
    (0, _chai.expect)(compilation.assets['bundle.js'].size).to.be.a.function;
  });

  it('should call take allow to emit assets at a sub folder', function () {
    // Setup
    var assets = {
      'bundle.js': 'some code here'
    };
    var callback = _sinon2.default.spy();
    var subfolder = 'js';
    // Do it
    (0, _emitAssets2.default)(compilation, assets, subfolder, callback);
    (0, _chai.expect)(compilation.assets[subfolder + '/bundle.js']).to.exist;
  });

  it('should call the callback as the third argument', function () {
    // Setup
    var assets = {
      'bundle.js': 'some code here'
    };
    var callback = _sinon2.default.spy();
    // Do it
    (0, _emitAssets2.default)(compilation, assets, callback);
    (0, _chai.expect)(callback.called).to.be.true;
  });

  it('should call the callback as the fourth argument', function () {
    // Setup
    var assets = {
      'bundle.js': 'some code here'
    };
    var callback = _sinon2.default.spy();
    // Do it
    (0, _emitAssets2.default)(compilation, assets, '', callback);
    (0, _chai.expect)(callback.called).to.be.true;
  });
}); /* eslint-disable no-unused-expressions */