'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Create the base template, returning a top and a bottom part
 *
 * @param  {String} dest The URL carte-blanche should be at
 * @return {Object}      The template split into two parts
 */
var createBaseTemplate = function createBaseTemplate(dest, commonsChunkFilename) {
  return {
    top: '\n<!DOCTYPE html>\n<html>\n  <head>\n    <meta charset="UTF-8">\n    <title>CarteBlanche</title>\n    <link rel="stylesheet" type="text/css" href="' + (dest ? '/' + _path2.default.join(dest, 'client-bundle.css') : 'client-bundle.css') + '" />\n  </head>\n  <body>\n    <div id=\'carte-blanche-root\'></div>\n',
    bottom: (commonsChunkFilename ? '    <script src="/' + commonsChunkFilename + '"></script>' : '') + '\n    <script src="' + (dest ? '/' + _path2.default.join(dest, 'client-bundle.js') : 'client-bundle.js') + '"></script>\n    <script src="' + (dest ? '/' + _path2.default.join(dest, 'user-bundle.js') : 'user-bundle.js') + '"></script>\n  </body>\n</html>'
  };
};

/**
 * Create HTML from a base template with injected styles and scripts and the
 * common chunk
 *
 * @param {Object} [options]              The options
 * @param {String} [options.dest]         The subfolder where the bundles are
 * @param {Array}  [options.extraScripts] An array of strings filled with JS code
 * @param {Array}  [options.extraStyles]              --“--               CSS code
 * @param {Array}  [options.commonsChunkFilename] The common chunk filename
 *
 * @return {String}        The finished HTML
 */
/* eslint-disable max-len */
var createHTML = function createHTML(options) {
  var _ref = options || {};

  var dest = _ref.dest;
  var extraScripts = _ref.extraScripts;
  var extraStyles = _ref.extraStyles;
  var commonsChunkFilename = _ref.commonsChunkFilename;

  var baseTemplate = createBaseTemplate(dest || '', commonsChunkFilename || '');
  // If there's no extraScripts or extraStyles return the basetemplate
  if (!extraScripts && !extraStyles) {
    return baseTemplate.top + '\n' + baseTemplate.bottom;
  }

  // Put together the injected content
  var injectedContent = '';
  if (extraScripts) {
    injectedContent += '    <script>' + extraScripts.join('\n') + '</script>\n';
  }
  if (extraStyles) {
    injectedContent += '    <style>' + extraStyles.join('\n') + '</style>\n';
  }
  return '' + baseTemplate.top + injectedContent + baseTemplate.bottom;
};

exports.default = createHTML;