'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _isString = require('lodash/isString');

var _isString2 = _interopRequireDefault(_isString);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Emit some assets to a compilation
 *
 * @param  {Object}   compilation The compilation we want to emit the assets from
 * @param  {Object}   assets      The assets we want to emit, keyed by filename
 * @param  {String}   [subFolder] Optionally, emit the assets to a subfolder
 * @param  {Function} callback
 */

function emitAssets(compilation, assets, subFolder, callback) {
  var cb = callback || subFolder;
  var rootPath = (0, _isString2.default)(subFolder) && subFolder || '';
  // Emit carte-blanche assets
  Object.keys(assets).forEach(function (filename) {
    compilation.assets[_path2.default.join(rootPath, filename)] = { // eslint-disable-line no-param-reassign
      source: function source() {
        return assets[filename];
      },
      size: function size() {
        return assets[filename].length;
      }
    };
  });
  cb();
}

exports.default = emitAssets;