'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _constructorIndexInArray = require('./constructorIndexInArray');

var _constructorIndexInArray2 = _interopRequireDefault(_constructorIndexInArray);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Get the common chunk filename from the CommonsChunkPlugin options
 *
 * @param  {Object} commonsChunkOptions
 *
 * @return {String}                     The common chunk filename
 */
var getCommonsChunkFilename = function getCommonsChunkFilename(pluginOptions) {
  // Detect CommonsChunkPlugin usage
  var commonsChunkPluginIndex = (0, _constructorIndexInArray2.default)(pluginOptions, 'CommonsChunkPlugin');

  // Get the filename of the common chunk
  var commonsChunkFilename = void 0;
  if (commonsChunkPluginIndex !== false) {
    var commonsChunkOptions = pluginOptions[commonsChunkPluginIndex];
    // Called like "new CommonsChunkPlugin('somename')"
    if (commonsChunkOptions.filenameTemplate === commonsChunkOptions.chunkNames) {
      commonsChunkFilename = commonsChunkOptions.chunkNames + '.js';
      // Called like "new CommonsChunkPlugin({ filename: 'somefilename.js' })"
    } else if (commonsChunkOptions.filenameTemplate) {
        commonsChunkFilename = commonsChunkOptions.filenameTemplate;
        // Called like "new CommonsChunkPlugin({ name: 'somename' })"
      } else if (commonsChunkOptions.chunkNames) {
          commonsChunkFilename = commonsChunkOptions.chunkNames + '.js';
          // Don't know if this can actually happen, better to have it there just in case
        } else {
            // eslint-disable-next-line no-console
            console.log('[CarteBlanche] We detected you use the CommonsChunkPlugin, ' + 'but we could not detect the filename of the common chunk. Please use the ' + '"filename" option of the CommonsChunkPlugin.');
          }
  }
  return commonsChunkFilename;
};

exports.default = getCommonsChunkFilename;